@@ -1,6 +1,6 @@
 import random
 
-from mmaze.generator.base import BaseMazeGenerator
+from mmaze.generator.base import BaseMazeGenerator, set_cell
 from mmaze.maze import Maze
 from mmaze.cell import CellType
 
@@ -16,32 +16,27 @@ class Prims(BaseMazeGenerator):
     3. Add that wall to the Minimal Spanning Tree (MST), and the edge's other cell to V.
     4. Repeat steps 2 and 3 until V includes every cell in G.
     """
+    symmetry_ok = True
 
-    def __init__(self):
-        super().__init__()
-
-    def generate(self, width: int, height: int) -> Maze:
+    def _generate(self, width: int, height: int, symmetry: str = "none") -> Maze:
         m = Maze(width, height, CellType.WALL)
         # choose a random starting position
         row, col = m.random_position()
-        m.set(row, col, CellType.ROAD)
+        set_cell(m, (row, col), CellType.ROAD, symmetry)
 
         # created a weighted list of all vertices connected in the graph
         neighbors = m.find_neighbors(row, col, True)
 
-        # loop over all current neighbors, until empty
-        visited = 1
-
-        while visited < m.base_height * m.base_width:
+        while len(neighbors) >= 1:
             # find neighbor with lowest weight, make it current
             nn = random.randrange(len(neighbors))
             row, col = neighbors[nn]
-            visited += 1
-            m.set(row, col, CellType.ROAD)
+            set_cell(m, (row, col), CellType.ROAD, symmetry)
+
             neighbors = neighbors[:nn] + neighbors[nn + 1:]
             # connect that neighbor to a random neighbor with grid[posi] == 0
             nearest_n0, nearest_n1 = m.find_neighbors(row, col)[0]
-            m.set((row + nearest_n0) // 2, (col + nearest_n1) // 2, CellType.ROAD)
+            set_cell(m, ((row + nearest_n0) // 2, (col + nearest_n1) // 2), CellType.ROAD, symmetry)
 
             # find all unvisited neighbors of current, add them to neighbors
             unvisited = m.find_neighbors(row, col, True)
